@@ -25,41 +25,39 @@
 
 
 """
-This module provides utility classes wrapping standard readers to better fit
-Scalpel's needs.
+This module provides utility classes making easier the parsing of different
+types of files.
 """
 
-from csv import reader as load_csv
-from typing import Callable, Iterable, List, Optional, TextIO, Tuple
+
+from typing import Callable, Iterable, List, TextIO, Tuple
+from warnings import warn
+
+from metrics.scalpel.config.config import CsvConfiguration
 
 
 class CsvReader:
     """
-    The CsvReader allows to easily parse CSV files having a header line,
-    describing what the columns contain.
+    The CsvReader allows to easily parse CSV files that may have a header
+    line, describing what the columns contain.
     """
 
-    def __init__(self, stream: TextIO, separator: str = ',',
-                 quote_char: Optional[str] = None,
-                 row_filter: Callable[[List[str]], bool] = lambda r: True, has_header: bool = True) -> None:
+    def __init__(self, stream: TextIO, configuration: CsvConfiguration,
+                 row_filter: Callable[[List[str]], bool] = lambda r: True) -> None:
         """
         Creates a new CsvReader.
 
         :param stream: The stream to read as a CSV input.
-        :param separator: The value separator used in the CSV input.
-        :param quote_char: The character used to quote the fields in the
-                           CSV input, if any.
+        :param configuration: The configuration of the reader.
         :param row_filter: The filter allowing to select which rows to consider
                            from the CSV stream.
         """
         self._stream = stream
-        self._separator = separator
-        self._quote_char = quote_char
+        self._configuration = configuration
         self._row_filter = row_filter
         self._line_iterator = None
-        self._has_header = has_header
         self._keys = []
-        self._cache=None
+        self._cache = None
 
     def read(self) -> Iterable[List[Tuple[str, str]]]:
         """
@@ -76,13 +74,12 @@ class CsvReader:
 
         :return: The header of the CSV stream.
         """
-        self._line_iterator = iter(self._internal_read())
-        if self._has_header:
+        self._line_iterator = iter(self._configuration.create_loader(self._stream))
+        if self._configuration.has_header():
             self._keys = next(self._line_iterator)
         else:
             self._cache = next(self._line_iterator)
             self._keys = [str(i) for i in range(len(self._cache))]
-
         return self._keys
 
     def read_content(self) -> Iterable[List[Tuple[str, str]]]:
@@ -91,21 +88,23 @@ class CsvReader:
 
         :return: The content of the CSV stream.
         """
-        if self._cache is not None:
-            yield zip(self._keys,self._cache)
-        for line in self._line_iterator:
+        for index, line in self._read_lines():
             line = list(map(str.strip, line))
-            if self._row_filter(line):
+            if len(line) == len(self._keys):
                 yield zip(self._keys, line)
+            else:
+                warn(f'Line #{index} does not match header: {line}')
 
-    def _internal_read(self) -> Iterable[List[str]]:
+    def _read_lines(self) -> Iterable[Tuple[int, List[str]]]:
         """
-        Reads the associated CSV stream line-by-line.
+        Reads the associated CSV stream and only yields relevant lines.
 
-        :return: The lines of the CSV stream.
+        :return: The relevant lines from the CSV stream, and their index in
+                 this stream.
         """
-        if self._quote_char is None:
-            return load_csv(self._stream, delimiter=self._separator)
+        if self._cache is not None and self._row_filter(self._cache):
+            yield 1, self._cache
 
-        return load_csv(self._stream, delimiter=self._separator,
-                        quotechar=self._quote_char)
+        for index, line in enumerate(self._line_iterator):
+            if self._row_filter(line):
+                yield 2 + index, line
