@@ -1,7 +1,6 @@
 import dash_html_components as html
 import dash_bootstrap_components as dbc
 
-from metrics.studio.web.config import PLOTLY_LOGO
 
 navbar = dbc.Navbar(
     [
@@ -9,7 +8,6 @@ navbar = dbc.Navbar(
             # Use row and col to control vertical alignment of logo / brand
             dbc.Row(
                 [
-                    dbc.Col(html.Img(src=PLOTLY_LOGO, height="30px")),
                     dbc.Col(dbc.NavbarBrand("STUDIO", className="ml-1")),
                 ],
                 align="center",
